@@ -2,8 +2,8 @@
 """
 :Author: HuangJianYi
 :Date: 2020-05-29 09:40:42
-:LastEditTime: 2021-04-15 15:12:33
-:LastEditors: HuangJingCan
+@LastEditTime: 2021-04-27 11:35:18
+@LastEditors: HuangJianYi
 :description: 机台（盒子）
 """
 from seven_cloudapp.handlers.seven_base import *
@@ -48,7 +48,7 @@ class MachineHandler(SevenBaseHandler):
         box_style_type = int(self.get_param("box_style_type", 0))
         box_style_detail = self.get_param("box_style_detail")
         sale_type = int(self.get_param("sale_type", 0))
-        sale_date = self.get_param("sale_date")
+        sale_date = self.get_param("sale_date", "1900-01-01 00:00:00")
         sort_index = int(self.get_param("sort_index", 0))
         is_release = int(self.get_param("is_release", 0))
         is_false_prize = int(self.get_param("is_false_prize", 0))
@@ -147,19 +147,24 @@ class MachineListHandler(SevenBaseHandler):
         """
         :description: 获取机台列表
         :param act_id：活动id
+        :param series_id：IP系列id
         :param page_index：页索引
         :param page_size：页大小
         :return: list
         :last_editors: HuangJianYi
         """
         act_id = int(self.get_param("act_id", 0))
+        series_id = int(self.get_param("series_id", 0))
         page_index = int(self.get_param("page_index", 0))
         page_size = int(self.get_param("page_size", 10))
 
-        if act_id <= 0:
-            return self.reponse_json_error_params()
+        condition = "act_id=%s"
+        params = [act_id]
+        if series_id > 0:
+            condition += " and series_id=%s"
+            params.append(series_id)
 
-        page_list, total = MachineInfoModel(context=self).get_dict_page_list("*", page_index, page_size, "act_id=%s", "", "sort_index desc", act_id)
+        page_list, total = MachineInfoModel(context=self).get_dict_page_list("*", page_index, page_size, condition, "", "sort_index desc", params=params)
 
         for page in page_list:
             page["goods_detail"] = self.json_loads(page['goods_detail'])
